@@ -48,9 +48,7 @@
 #define SUMMARY_FETCH_BATCH_COUNT 150
 #define d(x)
 
-#define CAMEL_MAPI_FOLDER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_MAPI_FOLDER, CamelMapiFolderPrivate))
+extern gint camel_application_is_exiting;
 
 struct _CamelMapiFolderPrivate {
 
@@ -231,7 +229,7 @@ fetch_items_summary_cb (FetchItemsCallbackData *item_data, gpointer data)
 	if (item_data->total > 0)
                camel_operation_progress (NULL, (item_data->index * 100)/item_data->total);
 
-	if (camel_operation_cancel_check(NULL))
+	if (camel_operation_cancel_check (NULL) || camel_application_is_exiting)
 		return FALSE;
 
 	return TRUE;
@@ -545,7 +543,7 @@ deleted_items_sync_cb (FetchItemsCallbackData *item_data, gpointer data)
 		camel_operation_progress (NULL, (item_data->index * 100)/item_data->total);
 
 	/* Check if we have to stop */
-	if (camel_operation_cancel_check(NULL))
+	if (camel_operation_cancel_check (NULL) || camel_application_is_exiting)
 		return FALSE;
 
 	return TRUE;
@@ -600,7 +598,7 @@ mapi_sync_deleted (CamelSession *session, CamelSessionThreadMsg *msg)
 	camel_service_unlock (CAMEL_SERVICE (mapi_store), CAMEL_SERVICE_REC_CONNECT_LOCK);
 
 	/* Check if we have to stop */
-	if (camel_operation_cancel_check(NULL)) {
+	if (camel_operation_cancel_check (NULL) || camel_application_is_exiting) {
 		g_hash_table_destroy (server_messages);
 		return;
 	}
@@ -653,7 +651,7 @@ mapi_sync_deleted (CamelSession *session, CamelSessionThreadMsg *msg)
 		camel_operation_progress (NULL, (index * 100)/count); /* ;-) */
 
 		/* Check if we have to stop */
-		if (camel_operation_cancel_check(NULL)) {
+		if (camel_operation_cancel_check (NULL) || camel_application_is_exiting) {
 			g_hash_table_destroy (server_messages);
 			if (camel_folder_change_info_changed (changes))
 				camel_folder_changed (m->folder, changes);
@@ -1829,7 +1827,7 @@ camel_mapi_folder_init (CamelMapiFolder *mapi_folder)
 {
 	CamelFolder *folder = CAMEL_FOLDER (mapi_folder);
 
-	mapi_folder->priv = CAMEL_MAPI_FOLDER_GET_PRIVATE (mapi_folder);
+	mapi_folder->priv = G_TYPE_INSTANCE_GET_PRIVATE (mapi_folder, CAMEL_TYPE_MAPI_FOLDER, CamelMapiFolderPrivate);
 
 	folder->permanent_flags = CAMEL_MESSAGE_ANSWERED | CAMEL_MESSAGE_DELETED |
 		CAMEL_MESSAGE_DRAFT | CAMEL_MESSAGE_FLAGGED | CAMEL_MESSAGE_SEEN | CAMEL_MESSAGE_JUNK;
