@@ -54,10 +54,6 @@
 
 #define d(x) printf("%s:%s:%s \n", G_STRLOC, G_STRFUNC, x)
 
-#define CAMEL_MAPI_STORE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), CAMEL_TYPE_MAPI_STORE, CamelMapiStorePrivate))
-
 struct _CamelMapiStorePrivate {
 	gchar *profile;
 	ExchangeMapiConnection *conn;
@@ -758,7 +754,7 @@ mapi_store_dispose (GObject *object)
 {
 	CamelMapiStorePrivate *priv;
 
-	priv = CAMEL_MAPI_STORE_GET_PRIVATE (object);
+	priv = CAMEL_MAPI_STORE (object)->priv;
 
 	if (priv->conn != NULL) {
 		g_object_unref (priv->conn);
@@ -774,7 +770,7 @@ mapi_store_finalize (GObject *object)
 {
 	CamelMapiStorePrivate *priv;
 
-	priv = CAMEL_MAPI_STORE_GET_PRIVATE (object);
+	priv = CAMEL_MAPI_STORE (object)->priv;
 
 	g_free (priv->profile);
 	g_free (priv->storage_path);
@@ -912,22 +908,22 @@ mapi_store_get_folder_info_sync (CamelStore *store,
 			((CamelService *)store)->status = CAMEL_SERVICE_CONNECTING;
 			mapi_connect_sync ((CamelService *)store, cancellable, NULL);
 		}
-	}
 
-	/* update folders from the server only when asking for the top most or the 'top' is not known;
-	   otherwise believe the local cache, because folders sync is pretty slow operation to be done
-	   one every single question on the folder info */
-	if (((flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIPTION_LIST) != 0 ||
-	     (!(flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED)) ||
-	     (!mapi_store->priv->folders_synced) ||
-	     (top && *top && !camel_mapi_store_folder_id_lookup (mapi_store, top))) &&
-	    (check_for_connection ((CamelService *)store, NULL) || ((CamelService *)store)->status == CAMEL_SERVICE_CONNECTING)) {
-		if (!mapi_folders_sync (mapi_store, flags, error)) {
-			camel_service_unlock (CAMEL_SERVICE (store), CAMEL_SERVICE_REC_CONNECT_LOCK);
-			return NULL;
+		/* update folders from the server only when asking for the top most or the 'top' is not known;
+		   otherwise believe the local cache, because folders sync is pretty slow operation to be done
+		   one every single question on the folder info */
+		if (((flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIPTION_LIST) != 0 ||
+		    (!(flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED)) ||
+		    (!mapi_store->priv->folders_synced) ||
+		    (top && *top && !camel_mapi_store_folder_id_lookup (mapi_store, top))) &&
+		    (check_for_connection ((CamelService *)store, NULL) || ((CamelService *)store)->status == CAMEL_SERVICE_CONNECTING)) {
+			if (!mapi_folders_sync (mapi_store, flags, error)) {
+				camel_service_unlock (CAMEL_SERVICE (store), CAMEL_SERVICE_REC_CONNECT_LOCK);
+				return NULL;
+			}
+			camel_store_summary_touch ((CamelStoreSummary *)mapi_store->summary);
+			camel_store_summary_save ((CamelStoreSummary *)mapi_store->summary);
 		}
-		camel_store_summary_touch ((CamelStoreSummary *)mapi_store->summary);
-		camel_store_summary_save ((CamelStoreSummary *)mapi_store->summary);
 	}
 
 	camel_service_unlock (CAMEL_SERVICE (store), CAMEL_SERVICE_REC_CONNECT_LOCK);
@@ -1489,7 +1485,7 @@ camel_mapi_store_class_init (CamelMapiStoreClass *class)
 static void
 camel_mapi_store_init (CamelMapiStore *mapi_store)
 {
-	mapi_store->priv = CAMEL_MAPI_STORE_GET_PRIVATE (mapi_store);
+	mapi_store->priv = G_TYPE_INSTANCE_GET_PRIVATE (mapi_store, CAMEL_TYPE_MAPI_STORE, CamelMapiStorePrivate);
 }
 
 /* service methods */
