@@ -45,6 +45,7 @@ GQuark e_mapi_error_quark (void);
 
 typedef struct _ExchangeMapiConnection ExchangeMapiConnection;
 typedef struct _ExchangeMapiConnectionClass ExchangeMapiConnectionClass;
+typedef struct _ExchangeMapiConnectionPrivate ExchangeMapiConnectionPrivate;
 
 typedef enum {
 	MAPI_OPTIONS_FETCH_ATTACHMENTS = 1<<0,
@@ -143,6 +144,8 @@ typedef gboolean (*BuildReadPropsCB)	(ExchangeMapiConnection *conn, mapi_id_t fi
 
 struct _ExchangeMapiConnection {
 	GObject parent;
+
+	ExchangeMapiConnectionPrivate *priv;
 };
 
 struct _ExchangeMapiConnectionClass {
@@ -240,6 +243,7 @@ gboolean		exchange_mapi_create_profile (const gchar *username, const gchar *pass
 				       mapi_profile_callback_t cb, gpointer data, GError **perror);
 
 gboolean		exchange_mapi_delete_profile (const gchar *profile, GError **perror);
+void			exchange_mapi_rename_profile (const gchar *old_name, const gchar *new_name);
 
 /* utility functions */
 
